/* ************************************************************************** */
/*                                       _____           _                    */
/*  libp7/internals.h                   |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/05/12 01:16:06                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#ifndef LIBP7_INTERNALS_H
# define LIBP7_INTERNALS_H
# include <libp7.h>
# include <libusb-1.0/libusb.h>

/* Buffer sizes */
# define MAX_RAWDATA_SIZE 256
# define MAX_RAWDFLD_SIZE (8 + MAX_RAWDATA_SIZE)
# define MAX_ENCDFLD_SIZE (8 + (MAX_RAWDATA_SIZE * 2))
# define MAX_PACKET_SIZE (8 + MAX_ENCDFLD_SIZE + 2)

/* The following values are defined in fxReverse project documentation */
# define ACTIVE_TIMEOUT (10 * 1000) /* 10 seconds */
# define PASSVE_TIMEOUT (6 * 60 * 1000) /* 6 minutes */
# define SENDNG_TIMEOUT (0) /* unlimited */

/* libusb endpoints */
# define ENDPOINT_IN (LIBUSB_ENDPOINT_IN | LIBUSB_TRANSFER_TYPE_BULK)
# define ENDPOINT_OUT (LIBUSB_ENDPOINT_OUT | LIBUSB_TRANSFER_TYPE_ISOCHRONOUS)

/* ************************************************************************** */
/*  Packet I/O                                                                */
/* ************************************************************************** */
/* Main functions */
# include <libp7/internals/packetio.h>

/* Utilities */
int p7_send_basic(unsigned int type, unsigned int subtype);
int p7_send_ext(unsigned int type, unsigned int subtype,
	void *data, unsigned int size);
int p7_recv(p7_packet_t *packet);

/* ************************************************************************** */
/*  Useful globals                                                            */
/* ************************************************************************** */
/* Device handler */
extern libusb_device_handle *p7_lusb_handler;

/* Is active */
extern int p7_active;

/* active response */
extern p7_packet_t p7_response;
extern int p7_response_got;

/* last sent command */
extern unsigned int p7_last_sent_command;

/* ************************************************************************** */
/*  Utilities                                                                 */
/* ************************************************************************** */
/* Encoding/decoding functions */
unsigned int p7_encode(void *fnal, void *raw, unsigned int size);
unsigned int p7_decode(void *fnal, void *encoded, unsigned int size);

/* Checksum function */
unsigned int p7_checksum(uint8_t *packet, unsigned int size);

# include <libp7/internals/log.h>
#endif
