/* ************************************************************************** */
/*                                       _____           _                    */
/*  init.c                              |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/08/16 23:19:46                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#include <stdlib.h>
#include <libp7/internals.h>
#define casio_vendor 0x07CF
#define casio_product 0x6101

/**
 *	p7_error:
 *	The error.
 */

int p7_error = p7_noerror;

/**
 *	p7_active:
 *	Boolean to know if we are in active or passive mode.
 */

int p7_active;

/**
 *	p7_lusb_context:
 *	libusb context used by libp7.
 */

static libusb_context *p7_lusb_context = NULL;

/**
 *	p7_lusb_handler:
 *	Calculator connexion handler.
 */

libusb_device_handle *p7_lusb_handler = NULL;

/**
 *	p7_exit:
 *	De-initialize libp7.
 */

static void p7_exit(void)
{
	/* close calc handler */
	if (p7_lusb_handler) libusb_close(p7_lusb_handler);

	/* close libusb context */
	if (p7_lusb_context) libusb_exit(p7_lusb_context);
}

/**
 *	p7_init:
 *	Initialize libp7.
 *
 *	Creates the libusb context and connect to the calculator.
 *
 *	@return			if it worked (0 if no)
 */

int p7_init(void)
{
	/* set libp7 exit function */
	atexit(&p7_exit);

	/* open handle */
	log_info("creating libusb context");
	if (libusb_init(&p7_lusb_context)) {
		log_fatal("couldn't create libusb context");
		p7_error = p7_error_libusb;
		return (0);
	}

	/* get calculator handler */
	log_info("getting the device handler");
	p7_lusb_handler = libusb_open_device_with_vid_pid(p7_lusb_context,
		casio_vendor, casio_product);
	if (!p7_lusb_handler) {
		log_fatal("couldn't get the device handler");
		p7_error = p7_error_nocalc;
		return (0);
	}

	/* starting as active */
	p7_active = 1;

	/* initialization went alright */
	return (1);
}
