/* ************************************************************************** */
/*                                       _____           _                    */
/*  packet/send_ack.c                   |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/08/17 09:51:39                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#include <libp7/internals.h>

/*
 *	Types and subtypes
 */

#define T p7_pt_ack
#define ST_DEFAULT 0x00
#define ST_CONFIRM_OVERWRITE 0x01
#define ST_EXTENDED 0x02

/**
 *	p7_send_ack:
 *	Send basic command acknowledge.
 *
 *	Default response at successful packet reception.
 *
 *	@return				if it worked
 */

int p7_send_ack(void)
{
	return (p7_send_basic(T, ST_DEFAULT));
}

/**
 *	p7_send_ack_confirm_ow:
 *	Sends overwrite confirmation.
 *
 *	@return				if it worked
 */

int p7_send_ack_confirm_ow(void)
{
	return (p7_send_basic(T, ST_CONFIRM_OVERWRITE));
}

/**
 *	p7_send_ack_extended:
 *	Sends extended ack packet.
 */

int p7_send_ack_ext(void *data, unsigned int datasize)
{
	p7_error = p7_error_unknown;

	/* check datasize */
	if (datasize > 256) {
		p7_error = p7_error_internal;
		log_fatal("Extended ack data is too large, you moron ! [%u]", datasize);
		return (0);
	}

	/* send packet */
	return (p7_send_ext(T, ST_EXTENDED, data, datasize));
}
