/* ************************************************************************** */
/*                                       _____           _                    */
/*  packet/send_data.c                  |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/08/17 09:51:17                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#include <string.h>
#include <libp7/internals.h>

/*
 *	Type and subtypes
 */

#define T p7_pt_data
#define ST_DEFAULT 0x00

/**
 *	p7_send_data:
 *	Send data packet.
 *
 *	Carries 'raw' data in the context of a command. E.g. file data.
 *
 *	Maximum data size is 256 octets.
 *
 *	@arg	total		the total number of data packets in trans
 *	@arg	id			the packet id
 *	@arg	data		the data part
 *	@arg	datasize	the data part size (in bytes)
 *	@return				if it worked
 */

int p7_send_data(unsigned int total, unsigned int id,
	void *data, unsigned int datasize)
{
	/* check datasize */
	if (datasize > MAX_RAWDATA_SIZE) {
		p7_error = p7_error_internal;
		log_fatal("Data should not exceed %u ! [%u]",
			MAX_RAWDATA_SIZE, datasize);
		return (0);
	}

	/* check id */
	if (!total || id > total) {
		p7_error = p7_error_internal;
		log_fatal("The ID is greater than the total, wtf ? [%u/%u]",
			id, total);
		return (0);
	}

	/* make new buffer */
	unsigned char buf[8 + datasize];
	sprintf((char*)buf, "%04X" "%04X", total, id);
	memcpy(&buf[8], data, datasize);

	/* send packet */
	return (p7_send_ext(T, p7_last_sent_command, buf, 8 + datasize));
}
