/* ************************************************************************** */
/*                                       _____           _                    */
/*  protocol/getusername.c              |_   _|__  _   _| |__   ___ _   _     */
/*  | Project : libp7                     | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/08/18 05:46:06                               |___/     */
/*                                                                            */
/* ************************************************************************** */

#include <string.h>
#include <libp7/internals.h>

/**
 *	p7_username:
 *	Gets calculator username.
 *
 *	@arg	username	the username buffer (MUST be at least 9-bytes long)
 *	@return				if it worked
 */

int p7_getusername(char *username)
{
	p7_packet_t packet;

	/* ask for system info */
	log_info("querying device info");
	if (!p7_send_cmdsys_getinfo()) {
		p7_error = p7_error_unknown;
		log_fatal("couldn't send command packet, exiting");
		return (0);
	}

	/* get response packet */
	log_info("receiving response");
	if (!p7_receive(&packet) || packet.type != p7_pt_ack
	 || !packet.ack.extended) {
		p7_error = p7_error_unknown;
		log_fatal("didn't receive response/response wasn't \
an extended ack packet");
		return (0);
	}

	/* copy username */
	memcpy(username, packet.ack.username, 9);
	return (1);
}
